import React from 'react';
import { render, screen } from '@testing-library/react';
import ArticleCard from './index';

const item = {
  author: {
    name: 'John Doe',
    profile_page_path: '/john-doe',
    twitter_profile: 'johndoe',
    image: '/images/john-doe.png',
  },
  title: 'Sample Article',
  updated_at: '2022-02-01',
  created_at: '2022-01-01',
  path: '/sample-article',
  banner: 'sample-article-banner.jpg',
};

describe('ArticleCard', () => {
  it('should render Article Card with hasVariableComponent prop', () => {
    render(
      <ArticleCard
        item={item}
        width={200}
        height={200}
        showAuthorOnOneLine={false}
        hasVariableComponent
      />
    );

    const articleLink = screen.getByRole('link', { name: /Sample Article/i });

    expect(articleLink).toBeInTheDocument();
  });

  it('should render Article Card without hasVariableComponent prop', () => {
    render(
      <ArticleCard
        item={item}
        width={200}
        height={200}
        showAuthorOnOneLine={false}
        hasVariableComponent={false}
      />
    );

    const articleLink = screen.getByRole('link', { name: /Sample Article/i });
    expect(articleLink).toBeInTheDocument();
    expect(articleLink).not.toHaveAttribute('hasvariablecomponent');
  });
});
